==> connectagram_1.2.11.orig.tar.gz: connectagram-1.2.11/translations/connectagram_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Lanac</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Učitavanje</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pauzirano</translation>
    </message>
</context>
<context>
    <name>Definitions</name>
    <message>
        <source>Definitions</source>
        <translation>Definicija</translation>
    </message>
    <message>
        <source>Downloading definition...</source>
        <translation>Preuzimanje definicije...</translation>
    </message>
    <message>
        <source>Unsolved word</source>
        <translation>Neriješene riječi</translation>
    </message>
</context>
<context>
    <name>Dictionary</name>
    <message>
        <source>Definition from Wiktionary, the free dictionary</source>
        <translation>Definicija s Wikitonary, besplatnog riječnika</translation>
    </message>
    <message>
        <source>No definition found</source>
        <translation>Definicija nije pronađena</translation>
    </message>
    <message>
        <source>Unable to connect to Wiktionary</source>
        <translation>Nije moguće povezivanje na Wikitonary</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Ograda</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Izaberi jezik aplikacije:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemski jezik&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Bilješka</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Molimo vas da ponovno pokrenete aplikaciju kako bi izabrani jezik bio primjenjen.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nova igra</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Lagano</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Srednje</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Teško</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Jako teško</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Jezik:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Duljina riječi:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Broj riječi:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n slovo</numerusform>
            <numerusform>%n slova</numerusform>
            <numerusform>%n slova</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Prstenje</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Scores</source>
        <translation>Rezultati</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Rezultat</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Vrijeme</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Riječi</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Duljina</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Stepenice</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Uvijen</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Val</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Uspijeh</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Učitavanje</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pauzirano</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Definicija</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Trik</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Igra</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Izaberi</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Detalji</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Trik</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>D&amp;efinicija</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Rezultati</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Izlaz</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Postavke</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Jezik aplikacije</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>O &amp;programu</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt-u</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Izaberi igru</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Broj igre:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Zao nam je!</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Nije moguće započeti novu igru.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Cennectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Igra premetanja riječi</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 by Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Objavljeno pod &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; licencom.</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Definicija preuzeta s &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalji</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Uzorak</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Nastavak</translation>
    </message>
</context>
</TS>

==> connectagram_1.3.1.orig.tar.gz: connectagram-1.3.1/translations/connectagram_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Lanac</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Učitavanje</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pauzirano</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Ograda</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Izaberi jezik aplikacije:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemski jezik&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Bilješka</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Molimo vas da ponovno pokrenete aplikaciju kako bi izabrani jezik bio primjenjen.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nova igra</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Lagano</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Srednje</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Teško</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Jako teško</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Jezik:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Duljina riječi:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Broj riječi:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n slovo</numerusform>
            <numerusform>%n slova</numerusform>
            <numerusform>%n slova</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Prstenje</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Rezultat</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Vrijeme</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Riječi</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Duljina</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Stepenice</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Uvijen</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Val</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Uspijeh</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Učitavanje</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pauzirano</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Definicija</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Trik</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Igra</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Izaberi</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Detalji</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Trik</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>D&amp;efinicija</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Izlaz</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Postavke</translation>
    </message>
    <message>
        <source>&amp;Dark Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Jezik aplikacije</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>O &amp;programu</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt-u</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Izaberi igru</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Broj igre:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Zao nam je!</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Nije moguće započeti novu igru.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Cennectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Igra premetanja riječi</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 by Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Objavljeno pod &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; licencom.</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Definicija preuzeta s &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalji</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Uzorak</translation>
    </message>
</context>
</TS>
